@@ -45,7 +45,7 @@ tdeio_umountwrapper::tdeio_umountwrapper(const TQString& url)
 
     TQTimer *t = new TQTimer(this);
     connect(t, TQ_SIGNAL(timeout()), TQ_SLOT(progressAdvance()));
-    t->start(10, FALSE);
+    t->start(10, false);
 
     TDEProcess *p = new TDEProcess(this);
     *p << "tdeio_media_mounthelper";
